#
# Conditional build:
%bcond_with	msdblib		# use MS-style dblib instead of SYB-style
%bcond_without	kerberos5	# Kerberos5 support (via Heimdal)
#
# %%define tdsver - default protocol version; valid versions:
# 4.2 (used by Sybase SQLServer <= 10 and MS SQL Server 6.5)
# 4.6
# 5.0 (used by Sybase SQLServer >= 11)
# 7.0 (used by MS SQL Server 7.0) [spec default]
# 7.1 (used by MS SQL Server 2000)
# 7.2 (used by MS SQL Server 2005)
# 7.3 (used by MS SQL Server 2008)
# [7.4 (used by MS SQL Server 2012/2014) not supported yet]

%{!?tdsver:%define tdsver 7.0}

Summary:	Free implementation of Sybase's db-lib
Summary(pl.UTF-8):	Wolnodostępna implementacja db-lib firmy Sybase
Name:		freetds
Version:	0.95.8
Release:	1
License:	LGPL v2+
Group:		Libraries
Source0:	ftp://ftp.freetds.org/pub/freetds/stable/%{name}-%{version}.tar.bz2
# Source0-md5:	44b28f2ee1236c47de395193f9ee4810
Patch0:		%{name}-reserved.patch
Patch1:		%{name}-no-Llibdir.patch
URL:		http://www.freetds.org/
BuildRequires:	autoconf >= 2.53
BuildRequires:	automake
BuildRequires:	gettext-tools
%{?with_kerberos5:BuildRequires:	heimdal-devel}
BuildRequires:	libltdl-devel
BuildRequires:	libtool
BuildRequires:	openssl-devel
BuildRequires:	unixODBC-devel
Requires(post):	/sbin/ldconfig
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_sysconfdir	/etc/tds

%description
FreeTDS is a free (open source) implementation of Sybase's db-lib,
ct-lib, and ODBC libraries (which can be used also to work with MS SQL
databases). Currently, dblib and ctlib are most mature. Both of these
libraries have several programs known to compile and run against them.
ODBC is not quite as mature, but may work depending on your needs.

%description -l pl.UTF-8
FreeTDS to wolnodostępna (z otwartymi źródłami) implementacja
bibliotek db-lib, ct-lib i ODBC firmy Sybase (których można używać
także do pracy z bazami MS SQL). Aktualnie najlepiej działają dblib i
ctlib - istnieje trochę programów, o których wiadomo, że kompilują się
i działają z tymi bibliotekami. ODBC nie jest jeszcze na tyle
skończony, ale może działać w zależności od potrzeb.

%package devel
Summary:	FreeTDS header files
Summary(pl.UTF-8):	Pliki nagłówkowe FreeTDS
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
%{?with_kerberos5:Requires:	heimdal-devel}
Requires:	openssl-devel

%description devel
FreeTDS header files.

%description devel -l pl.UTF-8
Pliki nagłówkowe FreeTDS.

%package static
Summary:	FreeTDS static libraries
Summary(pl.UTF-8):	Statyczne biblioteki FreeTDS
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
FreeTDS static libraries.

%description static -l pl.UTF-8
Statyczne biblioteki FreeTDS.

%package odbc
Summary:	FreeTDS ODBC driver for unixODBC
Summary(pl.UTF-8):	Sterownik ODBC FreeTDS dla unixODBC
Group:		Libraries
Requires(post):	/sbin/ldconfig
Requires(post):	/usr/bin/odbcinst
Requires:	%{name} = %{version}-%{release}
Requires:	unixODBC

%description odbc
FreeTDS ODBC driver for unixODBC.

%description odbc -l pl.UTF-8
Sterownik ODBC FreeTDS dla unixODBC.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{?with_kerberos5:--enable-krb5=gssapi} \
	--disable-silent-rules \
	%{?with_msdblib:--with-msdblib} \
	--with-openssl \
	--with-tdsver=%{tdsver} \
	--with-unixodbc=/usr

%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	ETC=$RPM_BUILD_ROOT%{_sysconfdir}

cp -a src/pool/BUGS BUGS.pool
cp -a src/pool/README README.pool
cp -a src/pool/TODO TODO.pool

# ODBC driver, dlopen()ed
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libtdsodbc.{la,a}

# packaged as %doc
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
if [ -f /etc/freetds.conf ]; then
	mv -f /etc/freetds.conf %{_sysconfdir}/freetds.conf
fi

%postun	-p /sbin/ldconfig

%post odbc
/sbin/ldconfig
/usr/bin/odbcinst -i -d -r <<EOF
[FreeTDS]
Description = FreeTDS unixODBC Driver
Driver = %{_libdir}/libtdsodbc.so.0
Setup = %{_libdir}/libtdsodbc.so.0
EOF
/usr/bin/odbcinst -i -d -r <<EOF
[SQL Server]
Description = FreeTDS unixODBC Driver
Driver = %{_libdir}/libtdsodbc.so.0
Setup = %{_libdir}/libtdsodbc.so.0
EOF

%postun odbc -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS BUGS* ChangeLog NEWS README* TODO* doc/userguide
%attr(755,root,root) %{_bindir}/bsqldb
%attr(755,root,root) %{_bindir}/datacopy
%attr(755,root,root) %{_bindir}/defncopy
%attr(755,root,root) %{_bindir}/fisql
%attr(755,root,root) %{_bindir}/freebcp
%attr(755,root,root) %{_bindir}/tdspool
%attr(755,root,root) %{_bindir}/tsql
%attr(755,root,root) %{_libdir}/libct.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libct.so.4
%attr(755,root,root) %{_libdir}/libsybdb.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libsybdb.so.5
%dir %{_sysconfdir}
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/freetds.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/locales.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/pool.conf
%{_mandir}/man1/bsqldb.1*
%{_mandir}/man1/datacopy.1*
%{_mandir}/man1/defncopy.1*
%{_mandir}/man1/fisql.1*
%{_mandir}/man1/freebcp.1*
%{_mandir}/man1/tsql.1*
%{_mandir}/man5/freetds.conf.5*

%files devel
%defattr(644,root,root,755)
%doc doc/reference
%attr(755,root,root) %{_libdir}/libct.so
%attr(755,root,root) %{_libdir}/libsybdb.so
%{_libdir}/libct.la
%{_libdir}/libsybdb.la
%{_includedir}/bkpublic.h
%{_includedir}/cspublic.h
%{_includedir}/cstypes.h
%{_includedir}/ctpublic.h
%{_includedir}/odbcss.h
%{_includedir}/sqldb.h
%{_includedir}/sqlfront.h
%{_includedir}/sybdb.h
%{_includedir}/syberror*.h
%{_includedir}/sybfront.h
%{_includedir}/tds_sysdep_public.h

%files static
%defattr(644,root,root,755)
%{_libdir}/libct.a
%{_libdir}/libsybdb.a

%files odbc
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/bsqlodbc
%attr(755,root,root) %{_bindir}/osql
%attr(755,root,root) %{_libdir}/libtdsodbc.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libtdsodbc.so.0
%attr(755,root,root) %{_libdir}/libtdsodbc.so
%{_mandir}/man1/bsqlodbc.1*
%{_mandir}/man1/osql.1*
%changelog
* Fri Jun 26 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/freetds.git;a=log;h=master

* Thu Jun 25 2015 Jakub Bogusz <qboosh@pld-linux.org> 9ed9043
- updated to 0.95.8
- removed obsolete format-security patch
- added reserved patch (avoid using _names reserved for C implementation as identifiers)
- added no-Llibdir patch (avoid -L to libdir)

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> f1b4875
- x32 rebuild
- release 3 (by relup.sh)

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> 33c6f7c
- fixed firmat string error
- fixed install

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> d119a53
- updated gettext BR

* Sat Jan 18 2014 Jakub Bogusz <qboosh@pld-linux.org> 9b0c092
- updated Source0 URL

* Fri Jan 13 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> a47ebbf
- release 2

* Sun Aug 21 2011 Jakub Bogusz <qboosh@pld-linux.org> f7cbf8e
- updated to 0.91
- removed obsolete cvs-fixes patch

* Sun May 16 2010 sparky <sparky@pld-linux.org> a261210
- replaced BR: gettext with BR: gettext-devel

* Sat Apr 10 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 4d2860f
- release 5

* Mon Mar 16 2009 Elan Ruusamäe <glen@pld-linux.org> d4a544e
- release 4

* Mon Feb 23 2009 Arkadiusz Miśkiewicz <arekm@maven.pl> 95f5654
- release 3

* Wed Jun 18 2008 hawk <hawk@pld-linux.org> 213d06f
- merged fixes from freetds CVS, release 2

* Wed Jun 18 2008 hawk <hawk@pld-linux.org> 519025e
- few fixes from freetds CVS, helps with building some tds related packages

* Sat May 31 2008 Jakub Bogusz <qboosh@pld-linux.org> 8aede28
- updated to 0.82
- added hack for libtool 2.2

* Mon Sep 03 2007 Jan Rękorajski <baggins@pld-linux.org> b2b1c3b
- rel 2

* Tue Feb 13 2007 Elan Ruusamäe <glen@pld-linux.org> dbb092a
- tabs in preamble

* Mon Feb 12 2007 Jan Rękorajski <baggins@pld-linux.org> fe90d86
- converted to UTF-8

* Tue Jul 18 2006 Jakub Bogusz <qboosh@pld-linux.org> bde04e5
- updated to 0.64
- enabled SSL support (using openssl; gnutls is also available)
- separated odbc driver, register it in its post

* Mon Dec 12 2005 Elan Ruusamäe <glen@pld-linux.org> c12462d
- adapterized (sorted %verify attrs)

* Sat Sep 17 2005 Arkadiusz Miśkiewicz <arekm@maven.pl> 2af6d5d
- rebuild with readline 5.0

